@@ -94,7 +94,7 @@ inline double giac_log(double d){
 
 #include <stdexcept>
 #include "help.h"
-#if !defined(GIAC_HAS_STO_38) // && !defined(ConnectivityKit) && !defined(BESTA_OS)
+#if 1 // !defined(GIAC_HAS_STO_38) // && !defined(ConnectivityKit) && !defined(BESTA_OS)
 #include "tinymt32.h"
 #endif
 
@@ -206,7 +206,6 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     smallint=256, // max small int to make modular oply operations with int
     max_series_expansion_order=64, // max auto order for series expansion
     max_texpand_expansion_order=64,
-    series_default_order=20,
     max_numexp=100
   };
   extern const char cas_suffixe[];
@@ -228,10 +227,10 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   extern bool CAN_USE_LAPACK;
   extern bool simplify_sincosexp_pi;
 #ifndef RTOS_THREADX
-#ifndef BESTA_OS
+  //#ifndef BESTA_OS
   extern int CALL_LAPACK; // lapack is used if dim of matrix is >= CALL_LAPACK
   // can be changed using shell variable GIAC_LAPACK in icas
-#endif
+  //#endif
 #endif
   extern int FACTORIAL_SIZE_LIMIT;
   extern int GAMMA_LIMIT;
@@ -291,7 +290,17 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
 #ifdef TIMEOUT
   void control_c();
 #else
+#if 0
 #define control_c() if (ctrl_c) { interrupted = true; CERR << "Throwing exception for user interruption." << std::endl; throw(std::runtime_error("Stopped by user interruption.")); }
+#else
+#define control_c() if (ctrl_c) { \
+interrupted = true; \
+std::string source_path = __FILE__; \
+std::string source_filename = source_path.substr(source_path.find_last_of("/\\") + 1); \
+CERR << "Throwing exception for user interruption (" << source_filename << ":" << __LINE__ << ")" << std::endl; \
+throw(std::runtime_error("Stopped by user interruption.")); \
+}
+#endif
 #endif // TIMEOUT
 #endif // !NSPIRE, !FIR
 
@@ -528,10 +537,11 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     bool _try_parse_i_;
     bool _specialtexprint_double_;
     bool _atan_tan_no_floor_;
+    bool _keep_acosh_asinh_;
     bool _keep_algext_;
     int _angle_mode_;
     int _bounded_function_no_;
-    int _series_flags_; // bit1= full simplify, bit2=1 for truncation, bit3=atan does not rewrite sin/cos to tan
+    int _series_flags_; // bit1= full simplify, bit2=1 for truncation, bit3=atan does not rewrite sin/cos to tan, bit4=no back conversion, bit5=write<<1,1>> with series_variable_name, bit 6=write O() instead of order_size
     int _step_infolevel_; 
     int _default_color_;
     double _epsilon_;
@@ -554,7 +564,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     parser_lexer _pl;
     int _prog_eval_level_val ;
     int _eval_level;
-#if defined(GIAC_HAS_STO_38) || defined(ConnectivityKit)
+#if 0 // defined(GIAC_HAS_STO_38) || defined(ConnectivityKit)
     unsigned int _rand_seed;
 #else
     tinymt32_t _rand_seed;
@@ -576,6 +586,8 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
     double _total_time_;
     void * _evaled_table_;
     void * _extra_ptr_;
+    char _series_variable_name_;
+    unsigned short _series_default_order_;
     global();  
     ~global();
     global & operator = (const global & g);
@@ -632,6 +644,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   std::string autosimplify(GIAC_CONTEXT);
   std::string autosimplify(const std::string & s,GIAC_CONTEXT);
 
+  bool csv_guess(const char * data,int count,char & sep,char & nl,char & decsep);
   std::string & format_double(GIAC_CONTEXT);
 
   int check_thread(context * contextptr);
@@ -683,6 +696,9 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   bool & atan_tan_no_floor(GIAC_CONTEXT);
   void atan_tan_no_floor(bool b,GIAC_CONTEXT);
 
+  bool & keep_acosh_asinh(GIAC_CONTEXT);
+  void keep_acosh_asinh(bool b,GIAC_CONTEXT);
+
   bool & keep_algext(GIAC_CONTEXT);
   void keep_algext(bool b,GIAC_CONTEXT);
 
@@ -704,6 +720,12 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   bool & approx_mode(GIAC_CONTEXT);
   void approx_mode(bool b,GIAC_CONTEXT);
 
+  char & series_variable_name(GIAC_CONTEXT);
+  void series_variable_name(char b,GIAC_CONTEXT);
+
+  unsigned short & series_default_order(GIAC_CONTEXT);
+  void series_default_order(unsigned short b,GIAC_CONTEXT);
+
   vecteur & history_in(GIAC_CONTEXT);
   vecteur & history_out(GIAC_CONTEXT);
 
@@ -790,7 +812,7 @@ Boolean isLegalUTF8Sequence(const UTF8 *source, const UTF8 *sourceEnd);
   // void eval_level(int b,GIAC_CONTEXT);
   thread_param * thread_param_ptr(const context * contextptr);
 
-#if defined(GIAC_HAS_STO_38) || defined(ConnectivityKit)
+#if 0 // defined(GIAC_HAS_STO_38) || defined(ConnectivityKit)
   unsigned int & rand_seed(GIAC_CONTEXT);
 #else
   tinymt32_t * rand_seed(GIAC_CONTEXT);
