@@ -98,11 +98,20 @@ namespace giac {
 
    string string2mathml(const string & m){
      string s=m;
+#if 0
+     size_t ms=m.size();
+     for (size_t i=0;i<ms;++i){
+       if (m[i]=='\\')
+	 s+="\\\\";
+       else
+	 s+=m[i];
+     }
+#endif
      string t="";
-     string mat[4]={"&","<",">","\n"};
-     string rep[4]={"&amp;","&lt;","&gt;","</mi></mtd></mtr><mtr><mtd><mi>"};
+     string mat[]={"&","<",">","\n"};
+     string rep[]={"&amp;","&lt;","&gt;","</mi></mtd></mtr><mtr><mtd><mi>"};
      //start with & before adding new ones
-     for(int siz=0;siz<4;siz++){
+     for(int siz=0;siz<sizeof(mat)/sizeof(string);siz++){
        int c=0,k=-1,le=s.length();
        while (c<le){
          k=s.find(mat[siz],c);
@@ -482,8 +491,12 @@ namespace giac {
   // --------------------------- provenant de derive ----------------------------
 
   static string mathml_printasderive(const gen & feuille,GIAC_CONTEXT){
-    if (feuille.type!=_VECT || feuille._VECTptr->size()<2)
-      return "<msup><mrow><mo>(</mo>"+gen2mathml(feuille,contextptr)+"<mo>)</mo></mrow><mi>'</mi></msup>";
+    if (feuille.type!=_VECT || feuille._VECTptr->size()<2){
+      if (feuille.type==_IDNT || feuille.type<=_CPLX || feuille.is_symb_of_sommet(at_derive))
+	return gen2mathml(feuille,contextptr)+"'";
+      else
+	return "<msup><mrow><mo>(</mo>"+gen2mathml(feuille,contextptr)+"<mo>)</mo></mrow><mi>'</mi></msup>";
+    }
     vecteur & v = *feuille._VECTptr;
     bool needpar=v[0].type==_SYMB;
     if (v.size()>2)
@@ -769,7 +782,7 @@ namespace giac {
   static string svg_text(gen A, string legende, svg_attribut attr,double xmin,double xmax,double ymin,double ymax,GIAC_CONTEXT){
     double x_scale=(xmax-xmin)/10;
     double y_scale=(ymax-ymin)/10;
-    double fontscale=0.4*x_scale;
+    double fontscale=0.3*x_scale;
     double ratio=y_scale/x_scale/0.6;
     if (legende=="")
       return legende;
@@ -1158,7 +1171,11 @@ namespace giac {
     if ( (mys.feuille.type==_VECT) && (mys.feuille._VECTptr->empty()) )
       return string(provisoire_mbox_begin)+mys.sommet.ptr()->print(contextptr)+string("()")+string(provisoire_mbox_end);
     if ( (mys.feuille.type!=_VECT) || (mys.feuille._VECTptr->front().type==_VECT)){
-
+      if (mys.sommet==at_factorial){
+	if (mys.feuille.type==_SYMB)
+	  return "<mrow><mo>(</mo>" + gen2mathml(mys.feuille,contextptr) +"<mo>)</mo></mrow><mtext>!</mtext>";
+	return gen2mathml(mys.feuille,contextptr)+"<mtext>!</mtext>";
+      }
       if ((mys.sommet==at_neg) || (mys.sommet==at_plus)){
 	if (mys.feuille.type!=_SYMB) 
 	  return string("<mo>")+mys.sommet.ptr()->print(contextptr)+"</mo>"+gen2mathml(mys.feuille,contextptr); 
@@ -1172,11 +1189,8 @@ namespace giac {
 	  + string("</mrow></mfrac>");
       }
       if (mys.sommet==at_pow) {
-
 	 return "<msup><mrow>"+gen2mathml((*(mys.feuille._VECTptr))[0],contextptr)+"</mrow><mrow>"+gen2mathml((*(mys.feuille._VECTptr))[1],contextptr)+"</mrow></msup>";
-      
-
-	 }
+      }
       return string(provisoire_mbox_begin) +mys.sommet.ptr()->print(contextptr)+ string(provisoire_mbox_end)
 	+ "<mrow><mo>(</mo>" + gen2mathml(mys.feuille,contextptr) +"<mo>)</mo></mrow>" ;
     }
@@ -1313,7 +1327,11 @@ namespace giac {
   }
 #endif
 
-  static string idnt2mathml(const string & sorig){
+  static string indice_mathml(const string & s1,const string & s2){
+    return "<msub><mi>"+s1+"</mi><mn>"+s2+"</mn></msub>";
+  }
+
+  static string idnt2mathml_(const string & sorig){
     string s0=sorig;
     int n=int(s0.size()),j;
     for (j=n-1;j>=2;--j){
@@ -1356,6 +1374,14 @@ namespace giac {
     return s0;
   }
 
+  static string idnt2mathml(const string & s0){
+    int n=int(s0.size()),j;
+    for (j=n-1;j>=1;--j){
+      if (j<n-1 && s0[j]=='_')
+	return indice_mathml(idnt2mathml_(s0.substr(0,j)),s0.substr(j+1,n-1-j));
+    }
+    return "<mi>"+idnt2mathml_(s0)+"</mi>";
+  }
 
   string gen2mathml(const gen &e, string &svg,GIAC_CONTEXT){
     string part_re="", part_im="<mi>i</mi>";
@@ -1405,19 +1431,31 @@ namespace giac {
 	return "<mi>&pi;</mi>";
       if (e==undef)
 	return "<mi>undef</mi>";
-      return  "<mi>"+idnt2mathml(e.print(contextptr))+"</mi>";
+      return  idnt2mathml(e.print(contextptr));
     case _SYMB: {
       gen tmp=aplatir_fois_plus(e);
       if (tmp.type!=_SYMB)
 	return gen2mathml(tmp,svg,contextptr);
       return symbolic2mathml(*tmp._SYMBptr, svg,contextptr);
     }
-    case _VECT:                        
+    case _VECT: {
+      vector<int> V; int p=0;
+      if (is_mod_vecteur(*e._VECTptr,V,p) && p!=0){
+	gen gm=makemodquoted(unmod(e),p);
+	return gen2mathml(gm,svg,contextptr);
+      }
       if (e.subtype==_SPREAD__VECT)
 	return spread2mathml(*e._VECTptr,1,contextptr); //----------------v??rifier le 2??me param??tre
-      if (e.subtype!=_SEQ__VECT && ckmatrix(*e._VECTptr))
+      if (e.subtype!=_SEQ__VECT && ckmatrix(*e._VECTptr)){
+	vector< vector<int> > M; p=0;
+	if (is_mod_matrice(*e._VECTptr,M,p) && p!=0){
+	  gen gm=makemodquoted(unmod(e),p);
+	  return gen2mathml(gm,svg,contextptr);
+	}
 	return matrix2mathml(*e._VECTptr,contextptr);
+      }
       return _VECT2mathml(*e._VECTptr,e.subtype, svg,contextptr);
+    }
     case _SPOL1:
       return _SPOL12mathml(*e._SPOL1ptr,svg,contextptr);
     case _POLY:
@@ -1455,11 +1493,13 @@ namespace giac {
   unsigned max_prettyprint_equation=5000;
   gen _mathml(const gen & g,GIAC_CONTEXT){
     if ( g.type==_STRNG && g.subtype==-1) return  g;
+#ifndef EMCC
     if (g.type==_VECT && g.subtype==_SEQ__VECT && g._VECTptr->size()>1 && (*g._VECTptr)[1].type==_STRNG && *((*g._VECTptr)[1]._STRNGptr)!="Done"){
       ofstream of((*g._VECTptr)[1]._STRNGptr->c_str());
       of << gen2mathmlfull(g._VECTptr->front(),contextptr) << endl;
       return plus_one;
     }
+#endif
     unsigned ta=taille(g,max_prettyprint_equation);
     if (ta>max_prettyprint_equation)
       return string2gen("Expression_too_large",false);
